function [beta0] = generate_signal_vector(p, type)

    % inputs:
    % p: number signal parameters
    % type: type signal
    % output:
    % beta0: signal vector of p parameters
    % scaling: keep the effective signal energy = signal_energy
    if strcmp(type, 'iso')
        beta0 = randn(p, 1) / sqrt(p);
    end
end